<?php
/*
Plugin Name: WP Realtime Sitemap
Plugin URI: http://www.daniel-tweedy.co.uk/article/wp-realtime-sitemap-plugin/
Description: Adds a sitemap to your Wordpress blog that is always up-to-date. Add <!--wp-realtime-sitemap--> to any page or post and the site map will be added there. Use Options->WP Realtime Sitemap to set options.
Author: Daniel Tweedy
Version: 1.1
Author URI: http://www.daniel-tweedy.co.uk/
*/

/*
WP Realtime Sitemap is a Wordpress Plugin that will create a list of posts, pages, tags, archives from your Wordpress Blog.
Copyright (C) 2010 Daniel Tweedy

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

function remove_style(&$item, $key) {
        $item = preg_replace('/ style=\'font-size: .*;\'/', '', $item);
}

// To replace the <!--wp-realtime-sitemap--> with the actual sitemap
function wp_realtime_sitemap($text) {
	global $wpdb, $table_prefix;

	// Only perform plugin functionality if post/page text has <!--wp-realtime-sitemap-->|
	if (preg_match('|<!--wp-realtime-sitemap-->|', $text)) {

		// Get option values
		$orderby		= get_option('wp_realtime_sitemap_orderby');
		$showprivate		= get_option('wp_realtime_sitemap_showprivate');
		$showpages		= get_option('wp_realtime_sitemap_showpages');
		$showposts		= get_option('wp_realtime_sitemap_showposts');
		$showarchives		= get_option('wp_realtime_sitemap_showarchives');
		$showcategories		= get_option('wp_realtime_sitemap_showcategories');
		$showcategoriesastc	= get_option('wp_realtime_sitemap_showcategoriesastc');
		$showtags		= get_option('wp_realtime_sitemap_showtags');
		$showtagsastc		= get_option('wp_realtime_sitemap_showtagsastc');
		$displayorder		= get_option('wp_realtime_sitemap_displayorder');

		// Do order by
		switch ($orderby) {
			case 'datedesc':
				$sqlorder = 'ORDER BY `post_date` DESC';
				break;
			case 'dateasc':
				$sqlorder = 'ORDER BY `post_date`';
				break;
			case 'alphadesc':
				$sqlorder = 'ORDER BY `post_title` DESC';
				break;
			case 'alphaasc':
				$sqlorder = 'ORDER BY `post_title`';
				break;
		}

		// Pages: Yes/No?
		if ($showpages != 'no') {
			if ($orderby == 'datedesc' || $orderby == 'dateasc')
				$sort_column = 'post_date';

			if ($orderby == 'alphadesc' || $orderby == 'alphaasc')
				$sort_column = 'post_title';

			if ($orderby == 'datedesc' || $orderby == 'alphadesc')
				$sort_order = 'DESC';

			if ($orderby == 'dateasc' || $orderby == 'alphaasc')
				$sort_order = 'ASC';

			$pages = '<h3>Pages</h3>';
			$pages .= '<ul>' . wp_list_pages(array('sort_column' => $sort_column, 'sort_order' => $sort_order, 'title_li' => '', 'echo' => '0')) . '</ul>';
		}

		// Posts: Yes/No?
		if ($showposts != 'no') {
			// Show private: Yes/No?
			if ($showprivate == 'yes') {
				$sqlwhere = 'WHERE `post_type`="post" ';
			} else {
				$sqlwhere = 'WHERE `post_type`="post" AND `post_status`="publish" ';
			}

			$sqlposts = 'SELECT * FROM `' . $table_prefix . 'posts` ' . $sqlwhere . $sqlorder;
			$allposts = $wpdb->get_results($sqlposts);

			if (count($allposts) == 0) {
				$posts = '';
			} else {
				$posts = '<h3>Posts</h3><ul>';

				foreach($allposts as $thepost) {
					$permalink = get_permalink($thepost->ID);
					$posts .= '<li><a href="' . $permalink . '">' . $thepost->post_title . '</a></li>';
				}

				$posts .= '</ul>';
			}
		}

		if ($showarchives != 'no') {
			$archives = '<h3>Archives</h3><ul>' . wp_get_archives('type=monthly&echo=0') . '</ul>';
		}

		if ($showcategories != 'no') {
			$categories = '<h3>Categories</h3>';

			if ($showcategoriesastc != 'no') {
				$categories .= wp_tag_cloud(array('format' => 'flat', 'separator' => ' ', 'taxonomy' => 'category', 'echo' => '0'));
			} else {
				$categories .= preg_replace('/ style=\'font-size: .*;\'/', '', wp_tag_cloud(array('format' => 'list', 'taxonomy' => 'category', 'echo' => '0')));
			}
		}

		if ($showtags != 'no') {
			$tags = '<h3>Tags</h3>';

			if ($showtagsastc != 'no') {
				$tags .= wp_tag_cloud(array('format' => 'flat', 'separator' => ' ', 'echo' => '0'));
			} else {
				$tags .= preg_replace('/ style=\'font-size: .*;\'/', '', wp_tag_cloud(array('format' => 'list', 'echo' => '0')));
			}
		}

		// 1: Pages, Posts, Archives, Categories, Tags
		if ($displayorder == 1)
			$data = $pages . $posts . $archives . $categories . $tags;

		// 2: Pages, Posts, Archives, Tags, Categories
		if ($displayorder == 2)
			$data = $pages . $posts . $archives . $tags . $categories;

		// 3: Pages, Posts, Categories, Archives, Tags
		if ($displayorder == 3)
			$data = $pages . $posts . $categories . $archives . $tags;

		// 4: Pages, Posts, Categories, Tags, Archives
		if ($displayorder == 4)
			$data = $pages . $posts . $categories . $tags . $archives;

		// 5: Pages, Posts, Tags, Archives, Categories
		if ($displayorder == 5)
			$data = $pages . $posts . $tags . $archives . $categories;

		// 6: Pages, Posts, Tags, Categories, Archives
		if ($displayorder == 6)
			$data = $pages . $posts . $tags . $categories . $archives;

		// 7: Pages, Archives, Posts, Categories, Tags
		if ($displayorder == 7)
			$data = $pages . $archives . $posts . $categories . $tags;

		// 8: Pages, Archives, Posts, Tags, Categories
		if ($displayorder == 8)
			$data = $pages . $archives . $posts . $tags . $categories;

		// 9: Pages, Archives, Categories, Posts, Tags
		if ($displayorder == 9)
			$data = $pages . $archives . $categories . $posts . $tags;

		// 10: Pages, Archives, Categories, Tags, Posts
		if ($displayorder == 10)
			$data = $pages . $archives . $categories . $tags . $posts;

		// 11: Pages, Archives, Tags, Posts, Categories
		if ($displayorder == 11)
			$data = $pages . $archives . $tags . $posts . $categories;

		// 12: Pages, Archives, Tags, Categories, Posts
		if ($displayorder == 12)
			$data = $pages . $archives . $tags . $categories . $posts;

		// 13: Pages, Categories, Posts, Archives, Tags
		if ($displayorder == 13)
			$data = $pages . $categories . $posts . $archives . $tags;

		// 14: Pages, Categories, Posts, Tags, Archives
		if ($displayorder == 14)
			$data = $pages . $categories . $posts . $tags . $archives;

		// 15: Pages, Categories, Archives, Posts, Tags
		if ($displayorder == 15)
			$data = $pages . $categories . $archives . $posts . $tags;

		// 16: Pages, Categories, Archives, Tags, Posts
		if ($displayorder == 16)
			$data = $pages . $categories . $archives . $tags . $posts;

		// 17: Pages, Categories, Tags, Posts, Archives
		if ($displayorder == 17)
			$data = $pages . $categories . $tags . $posts . $archives;

		// 18: Pages, Categories, Tags, Archives, Posts
		if ($displayorder == 18)
			$data = $pages . $categories . $tags . $archives . $posts;

		// 19: Pages, Tags, Posts, Archives, Categories
		if ($displayorder == 19)
			$data = $pages . $tags . $posts . $archives . $categories;

		// 20: Pages, Tags, Posts, Categories, Archives
		if ($displayorder == 20)
			$data = $pages . $tags . $posts . $categories . $archives;

		// 21: Pages, Tags, Archives, Posts, Categories
		if ($displayorder == 21)
			$data = $pages . $tags . $archives . $posts . $categories;

		// 22: Pages, Tags, Archives, Categories, Posts
		if ($displayorder == 22)
			$data = $pages . $tags . $archives . $categories . $posts;

		// 23: Pages, Tags, Categories, Posts, Archives
		if ($displayorder == 23)
			$data = $pages . $tags . $categories . $posts . $archives;

		// 24: Pages, Tags, Categories, Archives, Posts
		if ($displayorder == 24)
			$data = $pages . $tags . $categories . $archives . $posts;

		// 25: Posts, Pages, Archives, Categories, Tags
		if ($displayorder == 25)
			$data = $posts . $pages . $archives . $categories . $tags;

		// 26: Posts, Pages, Archives, Tags, Categories
		if ($displayorder == 26)
			$data = $posts . $pages . $archives . $tags . $categories;

		// 27: Posts, Pages, Categories, Archives, Tags
		if ($displayorder == 27)
			$data = $posts . $pages . $categories . $archives . $tags;

		// 28: Posts, Pages, Categories, Tags, Archives
		if ($displayorder == 28)
			$data = $posts . $pages . $categories . $tags . $archives;

		// 29: Posts, Pages, Tags, Archives, Categories
		if ($displayorder == 29)
			$data = $posts . $pages . $tags . $archives . $categories;

		// 30: Posts, Pages, Tags, Categories, Archives
		if ($displayorder == 30)
			$data = $posts . $pages . $tags . $categories . $archives;

		// 31: Posts, Archives, Pages, Categories, Tags
		if ($displayorder == 31)
			$data = $posts . $archives . $pages . $categories . $tags;

		// 32: Posts, Archives, Pages, Tags, Categories
		if ($displayorder == 32)
			$data = $posts . $archives . $pages . $tags . $categories;

		// 33: Posts, Archives, Categories, Pages, Tags
		if ($displayorder == 33)
			$data = $posts . $archives . $categories . $pages . $tags;

		// 34: Posts, Archives, Categories, Tags, Pages
		if ($displayorder == 34)
			$data = $posts . $archives . $categories . $tags . $pages;

		// 35: Posts, Archives, Tags, Pages, Categories
		if ($displayorder == 35)
			$data = $posts . $archives . $tags . $pages . $categories;

		// 36: Posts, Archives, Tags, Categories, Pages
		if ($displayorder == 36)
			$data = $posts . $archives . $tags . $categories . $pages;

		// 37: Posts, Categories, Pages, Archives, Tags
		if ($displayorder == 37)
			$data = $posts . $categories . $pages . $archives . $tags;

		// 38: Posts, Categories, Pages, Tags, Archives
		if ($displayorder == 38)
			$data = $posts . $categories . $pages . $tags . $archives;

		// 39: Posts, Categories, Archives, Pages, Tags
		if ($displayorder == 39)
			$data = $posts . $categories . $archives . $pages . $tags;

		// 40: Posts, Categories, Archives, Tags, Pages
		if ($displayorder == 40)
			$data = $posts . $categories . $archives . $tags . $pages;

		// 41: Posts, Categories, Tags, Pages, Archives
		if ($displayorder == 41)
			$data = $posts . $categories . $tags . $pages . $archives;

		// 42: Posts, Categories, Tags, Archives, Pages
		if ($displayorder == 42)
			$data = $posts . $categories . $tags . $archives . $pages;

		// 43: Posts, Tags, Pages, Archives, Categories
		if ($displayorder == 43)
			$data = $posts . $tags . $pages . $archives . $categories;

		// 44: Posts, Tags, Pages, Categories, Archives
		if ($displayorder == 44)
			$data = $posts . $tags . $pages . $categories . $archives;

		// 45: Posts, Tags, Archives, Pages, Categories
		if ($displayorder == 45)
			$data = $posts . $tags . $archives . $pages . $categories;

		// 46: Posts, Tags, Archives, Categories, Pages
		if ($displayorder == 46)
			$data = $posts . $tags . $archives . $categories . $pages;

		// 47: Posts, Tags, Categories, Pages, Archives
		if ($displayorder == 47)
			$data = $posts . $tags . $categories . $pages . $archives;

		// 48: Posts, Tags, Categories, Archives, Pages
		if ($displayorder == 48)
			$data = $posts . $tags . $categories . $archives . $pages;

		// 49: Archives, Pages, Posts, Categories, Tags
		if ($displayorder == 49)
			$data = $archives . $pages . $posts . $categories . $tags;

		// 50: Archives, Pages, Posts, Tags, Categories
		if ($displayorder == 50)
			$data = $archives . $pages . $posts . $tags . $categories;

		// 51: Archives, Pages, Categories, Posts, Tags
		if ($displayorder == 51)
			$data = $archives . $pages . $categories . $posts . $tags;

		// 52: Archives, Pages, Categories, Tags, Posts
		if ($displayorder == 52)
			$data = $archives . $pages . $categories . $tags . $posts;

		// 53: Archives, Pages, Tags, Posts, Categories
		if ($displayorder == 53)
			$data = $archives . $pages . $tags . $posts . $categories;

		// 54: Archives, Pages, Tags, Categories, Posts
		if ($displayorder == 54)
			$data = $archives . $pages . $tags . $categories . $posts;

		// 55: Archives, Posts, Pages, Categories, Tags
		if ($displayorder == 55)
			$data = $archives . $posts . $pages . $categories . $tags;

		// 56: Archives, Posts, Pages, Tags, Categories
		if ($displayorder == 56)
			$data = $archives . $posts . $pages . $tags . $categories;

		// 57: Archives, Posts, Categories, Pages, Tags
		if ($displayorder == 57)
			$data = $archives . $posts . $categories . $pages . $tags;

		// 58: Archives, Posts, Categories, Tags, Pages
		if ($displayorder == 58)
			$data = $archives . $posts . $categories . $tags . $pages;

		// 59: Archives, Posts, Tags, Pages, Categories
		if ($displayorder == 59)
			$data = $archives . $posts . $tags . $pages . $categories;

		// 60: Archives, Posts, Tags, Categories, Pages
		if ($displayorder == 60)
			$data = $archives . $posts . $tags . $categories . $pages;

		// 61: Archives, Categories, Pages, Posts, Tags
		if ($displayorder == 61)
			$data = $archives . $categories . $pages . $posts . $tags;

		// 62: Archives, Categories, Pages, Tags, Posts
		if ($displayorder == 62)
			$data = $archives . $categories . $pages . $tags . $posts;

		// 63: Archives, Categories, Posts, Pages, Tags
		if ($displayorder == 63)
			$data = $archives . $categories . $posts . $pages . $tags;

		// 64: Archives, Categories, Posts, Tags, Pages
		if ($displayorder == 64)
			$data = $archives . $categories . $posts . $tags . $pages;

		// 65: Archives, Categories, Tags, Pages, Posts
		if ($displayorder == 65)
			$data = $archives . $categories . $tags . $pages . $posts;

		// 66: Archives, Categories, Tags, Posts, Pages
		if ($displayorder == 66)
			$data = $archives . $categories . $tags . $posts . $pages;

		// 67: Archives, Tags, Pages, Posts, Categories
		if ($displayorder == 67)
			$data = $archives . $tags . $pages . $posts . $categories;

		// 68: Archives, Tags, Pages, Categories, Posts
		if ($displayorder == 68)
			$data = $archives . $tags . $pages . $categories . $posts;

		// 69: Archives, Tags, Posts, Pages, Categories
		if ($displayorder == 69)
			$data = $archives . $tags . $posts . $pages . $categories;

		// 70: Archives, Tags, Posts, Categories, Pages
		if ($displayorder == 70)
			$data = $archives . $tags . $posts . $categories . $pages;

		// 71: Archives, Tags, Categories, Pages, Posts
		if ($displayorder == 71)
			$data = $archives . $tags . $categories . $pages . $posts;

		// 72: Archives, Tags, Categories, Posts, Pages
		if ($displayorder == 72)
			$data = $archives . $tags . $categories . $posts . $pages;

		// 73: Categories, Pages, Posts, Archives, Tags
		if ($displayorder == 73)
			$data = $categories . $pages . $posts . $archives . $tags;

		// 74: Categories, Pages, Posts, Tags, Archives
		if ($displayorder == 74)
			$data = $categories . $pages . $posts . $tags . $archives;

		// 75: Categories, Pages, Archives, Posts, Tags
		if ($displayorder == 75)
			$data = $categories . $pages . $archives . $posts . $tags;

		// 76: Categories, Pages, Archives, Tags, Posts
		if ($displayorder == 76)
			$data = $categories . $pages . $archives . $tags . $posts;

		// 77: Categories, Pages, Tags, Posts, Archives
		if ($displayorder == 77)
			$data = $categories . $pages . $tags . $posts . $archives;

		// 78: Categories, Pages, Tags, Archives, Posts
		if ($displayorder == 78)
			$data = $categories . $pages . $tags . $archives . $posts;

		// 79: Categories, Posts, Pages, Archives, Tags
		if ($displayorder == 79)
			$data = $categories . $posts . $pages . $archives . $tags;

		// 80: Categories, Posts, Pages, Tags, Archives
		if ($displayorder == 80)
			$data = $categories . $posts . $pages . $tags . $archives;

		// 81: Categories, Posts, Archives, Pages, Tags
		if ($displayorder == 81)
			$data = $categories . $posts . $archives . $pages . $tags;

		// 82: Categories, Posts, Archives, Tags, Pages
		if ($displayorder == 82)
			$data = $categories . $posts . $archives . $tags . $pages;

		// 83: Categories, Posts, Tags, Pages, Archives
		if ($displayorder == 83)
			$data = $categories . $posts . $tags . $pages . $archives;

		// 84: Categories, Posts, Tags, Archives, Pages
		if ($displayorder == 84)
			$data = $categories . $posts . $tags . $archives . $pages;

		// 85: Categories, Archives, Pages, Posts, Tags
		if ($displayorder == 85)
			$data = $categories . $archives . $pages . $posts . $tags;

		// 86: Categories, Archives, Pages, Tags, Posts
		if ($displayorder == 86)
			$data = $categories . $archives . $pages . $tags . $posts;

		// 87: Categories, Archives, Posts, Pages, Tags
		if ($displayorder == 87)
			$data = $categories . $archives . $posts . $pages . $tags;

		// 88: Categories, Archives, Posts, Tags, Pages
		if ($displayorder == 88)
			$data = $categories . $archives . $posts . $tags . $pages;

		// 89: Categories, Archives, Tags, Pages, Posts
		if ($displayorder == 89)
			$data = $categories . $archives . $tags . $pages . $posts;

		// 90: Categories, Archives, Tags, Posts, Pages
		if ($displayorder == 90)
			$data = $categories . $archives . $tags . $posts . $pages;

		// 91: Categories, Tags, Pages, Posts, Archives
		if ($displayorder == 91)
			$data = $categories . $tags . $pages . $posts . $archives;

		// 92: Categories, Tags, Pages, Archives, Posts
		if ($displayorder == 92)
			$data = $categories . $tags . $pages . $archives . $posts;

		// 93: Categories, Tags, Posts, Pages, Archives
		if ($displayorder == 93)
			$data = $categories . $tags . $posts . $pages . $archives;

		// 94: Categories, Tags, Posts, Archives, Pages
		if ($displayorder == 94)
			$data = $categories . $tags . $posts . $archives . $pages;

		// 95: Categories, Tags, Archives, Pages, Posts
		if ($displayorder == 95)
			$data = $categories . $tags . $archives . $pages . $posts;

		// 96: Categories, Tags, Archives, Posts, Pages
		if ($displayorder == 96)
			$data = $categories . $tags . $archives . $posts . $pages;

		// 97: Tags, Pages, Posts, Archives, Categories
		if ($displayorder == 97)
			$data = $tags . $pages . $posts . $archives . $categories;

		// 98: Tags, Pages, Posts, Categories, Archives
		if ($displayorder == 98)
			$data = $tags . $pages . $posts . $categories . $archives;

		// 99: Tags, Pages, Archives, Posts, Categories
		if ($displayorder == 99)
			$data = $tags . $pages . $archives . $posts . $categories;

		// 100: Tags, Pages, Archives, Categories, Posts
		if ($displayorder == 100)
			$data = $tags . $pages . $archives . $categories . $posts;

		// 101: Tags, Pages, Categories, Posts, Archives
		if ($displayorder == 101)
			$data = $tags . $pages . $categories . $posts . $archives;

		// 102: Tags, Pages, Categories, Archives, Posts
		if ($displayorder == 102)
			$data = $tags . $pages . $categories . $archives . $posts;

		// 103: Tags, Posts, Pages, Archives, Categories
		if ($displayorder == 103)
			$data = $tags . $posts . $pages . $archives . $categories;

		// 104: Tags, Posts, Pages, Categories, Archives
		if ($displayorder == 104)
			$data = $tags . $posts . $pages . $categories . $archives;

		// 105: Tags, Posts, Archives, Pages, Categories
		if ($displayorder == 105)
			$data = $tags . $posts . $archives . $pages . $categories;

		// 106: Tags, Posts, Archives, Categories, Pages
		if ($displayorder == 106)
			$data = $tags . $posts . $archives . $categories . $pages;

		// 107: Tags, Posts, Categories, Pages, Archives
		if ($displayorder == 107)
			$data = $tags . $posts . $categories . $pages . $archives;

		// 108: Tags, Posts, Categories, Archives, Pages
		if ($displayorder == 108)
			$data = $tags . $posts . $categories . $archives . $pages;

		// 109: Tags, Archives, Pages, Posts, Categories
		if ($displayorder == 109)
			$data = $tags . $archives . $pages . $posts . $categories;

		// 110: Tags, Archives, Pages, Categories, Posts
		if ($displayorder == 110)
			$data = $tags . $archives . $pages . $categories . $posts;

		// 111: Tags, Archives, Posts, Pages, Categories
		if ($displayorder == 111)
			$data = $tags . $archives . $posts . $pages . $categories;

		// 112: Tags, Archives, Posts, Categories, Pages
		if ($displayorder == 112)
			$data = $tags . $archives . $posts . $categories . $pages;

		// 113: Tags, Archives, Categories, Pages, Posts
		if ($displayorder == 113)
			$data = $tags . $archives . $categories . $pages . $posts;

		// 114: Tags, Archives, Categories, Posts, Pages
		if ($displayorder == 114)
			$data = $tags . $archives . $categories . $posts . $pages;

		// 115: Tags, Categories, Pages, Posts, Archives
		if ($displayorder == 115)
			$data = $tags . $categories . $pages . $posts . $archives;

		// 116: Tags, Categories, Pages, Archives, Posts
		if ($displayorder == 116)
			$data = $tags . $categories . $pages . $archives . $posts;

		// 117: Tags, Categories, Posts, Pages, Archives
		if ($displayorder == 117)
			$data = $tags . $categories . $posts . $pages . $archives;

		// 118: Tags, Categories, Posts, Archives, Pages
		if ($displayorder == 118)
			$data = $tags . $categories . $posts . $archives . $pages;

		// 119: Tags, Categories, Archives, Pages, Posts
		if ($displayorder == 119)
			$data = $tags . $categories . $archives . $pages . $posts;

		// 120: Tags, Categories, Archives, Posts, Pages
		if ($displayorder == 120)
			$data = $tags . $categories . $archives . $posts . $pages;

		$text = preg_replace("|<!--wp-realtime-sitemap-->|", $data, $text);
	}

	return $text;

} // End wp_realtime_sitemap()

// Admin menu
function wp_realtime_sitemap_showadmin() {
	if (function_exists('add_options_page')) {
		add_options_page('wp-realtime-sitemap', 'WP Realtime Sitemap', 1, basename(__FILE__), 'wp_realtime_sitemap_showadmin_panel');
	}
}

function wp_realtime_sitemap_showadmin_panel() {

	$orderby		= get_option('wp_realtime_sitemap_orderby');
	$showprivate		= get_option('wp_realtime_sitemap_showprivate');
	$showpages		= get_option('wp_realtime_sitemap_showpages');
	$showposts		= get_option('wp_realtime_sitemap_showposts');
	$showarchives		= get_option('wp_realtime_sitemap_showarchives');
	$showcategories		= get_option('wp_realtime_sitemap_showcategories');
	$showcategoriesastc	= get_option('wp_realtime_sitemap_showcategoriesastc');
	$showtags		= get_option('wp_realtime_sitemap_showtags');
	$showtagsastc		= get_option('wp_realtime_sitemap_showtagsastc');
	$displayorder		= get_option('wp_realtime_sitemap_displayorder');

	// Add options if first time running
	add_option('wp_realtime_sitemap_orderby', 'datedesc', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showprivate', 'no', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showpages', 'yes', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showposts', 'yes', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showarchives', 'yes', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showcategories', 'yes', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showcategoriesastc', 'no', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showtags', 'yes', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_showtagsastc', 'no', 'WP Realtime Sitemap Plugin');
	add_option('wp_realtime_sitemap_displayorder', '1', 'WP Realtime Sitemap Plugin');

	// Get posted options
	$orderby = $_POST['orderby'];

	if (isset($_POST['info_update'])) {
		// Update settings
		$orderby		= $_POST['orderby'];
		$showprivate		= $_POST['showprivate'];
		$showpages		= $_POST['showpages'];
		$showposts		= $_POST['showposts'];
		$showarchives		= $_POST['showarchives'];
		$showcategories		= $_POST['showcategories'];
		$showcategoriesastc	= $_POST['showcategoriesastc'];
		$showtags		= $_POST['showtags'];
		$showtagsastc		= $_POST['showtagsastc'];
		$displayorder		= $_POST['displayorder'];

		update_option('wp_realtime_sitemap_orderby', $orderby);
		update_option('wp_realtime_sitemap_showprivate', $showprivate);
		update_option('wp_realtime_sitemap_showpages', $showpages);
		update_option('wp_realtime_sitemap_showposts', $showposts);
		update_option('wp_realtime_sitemap_showarchives', $showarchives);
		update_option('wp_realtime_sitemap_showcategories', $showcategories);
		update_option('wp_realtime_sitemap_showcategoriesastc', $showcategoriesastc);
		update_option('wp_realtime_sitemap_showtags', $showtags);
		update_option('wp_realtime_sitemap_showtagsastc', $showtagsastc);
		update_option('wp_realtime_sitemap_displayorder', $displayorder);
	} else {
		// Load settings from database
		$orderby		= get_option('wp_realtime_sitemap_orderby');
		$showprivate		= get_option('wp_realtime_sitemap_showprivate');
		$showpages		= get_option('wp_realtime_sitemap_showpages');
		$showposts		= get_option('wp_realtime_sitemap_showposts');
		$showarchives		= get_option('wp_realtime_sitemap_showarchives');
		$showcategories		= get_option('wp_realtime_sitemap_showcategories');
		$showcategoriesastc	= get_option('wp_realtime_sitemap_showcategoriesastc');
		$showtags		= get_option('wp_realtime_sitemap_showtags');
		$showtagsastc		= get_option('wp_realtime_sitemap_showtagsastc');
		$displayorder		= get_option('wp_realtime_sitemap_displayorder');
	}

?>

	<div class="wrap">
		<h2>WP Realtime Sitemap Options</h2>

		<form method="post">

		<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="orderby">Order Sitemap Pages/Posts By</label></th>
				<td><select name="orderby">
					<option <?php selected('datedesc', $orderby); ?> value="datedesc">Date descending (Default)</option>
					<option <?php selected('dateasc', $orderby); ?> value="dateasc">Date ascending</option>
					<option <?php selected('alphadesc', $orderby); ?> value="alphadesc">Alphabetical descending</option>
					<option <?php selected('alphaasc', $orderby); ?> value="alphaasc">Alphabetical ascending</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showprivate">Show Private Pages/Posts</label></th>
				<td><select name="showprivate">
					<option value="no" <?php selected('no', $showprivate); ?>>No, leave hidden (Default)</option>
					<option value="yes" <?php selected('yes', $showprivate); ?>>Yes, show hidden</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showpages">Show Pages</label></th>
				<td><select name="showpages">
					<option value="yes" <?php selected('yes', $showpages); ?>>Yes (Default)</option>
					<option value="no" <?php selected('no', $showpages); ?>>No</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showposts">Show Posts</label></th>
				<td><select name="showposts">
					<option value="yes" <?php selected('yes', $showposts); ?>>Yes (Default)</option>
					<option value="no" <?php selected('no', $showposts); ?>>No</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showarchives">Show Archives</label></th>
				<td><select name="showarchives">
					<option value="yes" <?php selected('yes', $showarchives); ?>>Yes (Default)</option>
					<option value="no" <?php selected('no', $showarchives); ?>>No</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showcategories">Show Categories</label></th>
				<td><select name="showcategories">
					<option value="yes" <?php selected('yes', $showcategories); ?>>Yes (Default)</option>
					<option value="no" <?php selected('no', $showcategories); ?>>No</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showcategoriesastc">Show Categories As Tag Cloud</label></th>
				<td><select name="showcategoriesastc">
					<option value="yes" <?php selected('yes', $showcategoriesastc); ?>>Yes</option>
					<option value="no" <?php selected('no', $showcategoriesastc); ?>>No (Default)</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showtags">Show Tags</label></th>
				<td><select name="showtags">
					<option value="yes" <?php selected('yes', $showtags); ?>>Yes (Default)</option>
					<option value="no" <?php selected('no', $showtags); ?>>No</option>
				</select></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="showtagsastc">Show Tags As Tag Cloud</label></th>
				<td><select name="showtagsastc">
					<option value="yes" <?php selected('yes', $showtagsastc); ?>>Yes</option>
					<option value="no" <?php selected('no', $showtagsastc); ?>>No (Default)</option>
				</select></td>
			</tr>
			<tr>
				<th scope="row">Display Order</th>
				<td><select name="displayorder">
					<option <?php selected('1', $displayorder); ?> value='1' /> 1: Pages, Posts, Archives, Categories, Tags</option>
					<option <?php selected('2', $displayorder); ?> value='2' /> 2: Pages, Posts, Archives, Tags, Categories</option>
					<option <?php selected('3', $displayorder); ?> value='3' /> 3: Pages, Posts, Categories, Archives, Tags</option>
					<option <?php selected('4', $displayorder); ?> value='4' /> 4: Pages, Posts, Categories, Tags, Archives</option>
					<option <?php selected('5', $displayorder); ?> value='5' /> 5: Pages, Posts, Tags, Archives, Categories</option>
					<option <?php selected('6', $displayorder); ?> value='6' /> 6: Pages, Posts, Tags, Categories, Archives</option>
					<option <?php selected('7', $displayorder); ?> value='7' /> 7: Pages, Archives, Posts, Categories, Tags</option>
					<option <?php selected('8', $displayorder); ?> value='8' /> 8: Pages, Archives, Posts, Tags, Categories</option>
					<option <?php selected('9', $displayorder); ?> value='9' /> 9: Pages, Archives, Categories, Posts, Tags</option>
					<option <?php selected('10', $displayorder); ?> value='10' /> 10: Pages, Archives, Categories, Tags, Posts</option>
					<option <?php selected('11', $displayorder); ?> value='11' /> 11: Pages, Archives, Tags, Posts, Categories</option>
					<option <?php selected('12', $displayorder); ?> value='12' /> 12: Pages, Archives, Tags, Categories, Posts</option>
					<option <?php selected('13', $displayorder); ?> value='13' /> 13: Pages, Categories, Posts, Archives, Tags</option>
					<option <?php selected('14', $displayorder); ?> value='14' /> 14: Pages, Categories, Posts, Tags, Archives</option>
					<option <?php selected('15', $displayorder); ?> value='15' /> 15: Pages, Categories, Archives, Posts, Tags</option>
					<option <?php selected('16', $displayorder); ?> value='16' /> 16: Pages, Categories, Archives, Tags, Posts</option>
					<option <?php selected('17', $displayorder); ?> value='17' /> 17: Pages, Categories, Tags, Posts, Archives</option>
					<option <?php selected('18', $displayorder); ?> value='18' /> 18: Pages, Categories, Tags, Archives, Posts</option>
					<option <?php selected('19', $displayorder); ?> value='19' /> 19: Pages, Tags, Posts, Archives, Categories</option>
					<option <?php selected('20', $displayorder); ?> value='20' /> 20: Pages, Tags, Posts, Categories, Archives</option>
					<option <?php selected('21', $displayorder); ?> value='21' /> 21: Pages, Tags, Archives, Posts, Categories</option>
					<option <?php selected('22', $displayorder); ?> value='22' /> 22: Pages, Tags, Archives, Categories, Posts</option>
					<option <?php selected('23', $displayorder); ?> value='23' /> 23: Pages, Tags, Categories, Posts, Archives</option>
					<option <?php selected('24', $displayorder); ?> value='24' /> 24: Pages, Tags, Categories, Archives, Posts</option>
					<option <?php selected('25', $displayorder); ?> value='25' /> 25: Posts, Pages, Archives, Categories, Tags</option>
					<option <?php selected('26', $displayorder); ?> value='26' /> 26: Posts, Pages, Archives, Tags, Categories</option>
					<option <?php selected('27', $displayorder); ?> value='27' /> 27: Posts, Pages, Categories, Archives, Tags</option>
					<option <?php selected('28', $displayorder); ?> value='28' /> 28: Posts, Pages, Categories, Tags, Archives</option>
					<option <?php selected('29', $displayorder); ?> value='29' /> 29: Posts, Pages, Tags, Archives, Categories</option>
					<option <?php selected('30', $displayorder); ?> value='30' /> 30: Posts, Pages, Tags, Categories, Archives</option>
					<option <?php selected('31', $displayorder); ?> value='31' /> 31: Posts, Archives, Pages, Categories, Tags</option>
					<option <?php selected('32', $displayorder); ?> value='32' /> 32: Posts, Archives, Pages, Tags, Categories</option>
					<option <?php selected('33', $displayorder); ?> value='33' /> 33: Posts, Archives, Categories, Pages, Tags</option>
					<option <?php selected('34', $displayorder); ?> value='34' /> 34: Posts, Archives, Categories, Tags, Pages</option>
					<option <?php selected('35', $displayorder); ?> value='35' /> 35: Posts, Archives, Tags, Pages, Categories</option>
					<option <?php selected('36', $displayorder); ?> value='36' /> 36: Posts, Archives, Tags, Categories, Pages</option>
					<option <?php selected('37', $displayorder); ?> value='37' /> 37: Posts, Categories, Pages, Archives, Tags</option>
					<option <?php selected('38', $displayorder); ?> value='38' /> 38: Posts, Categories, Pages, Tags, Archives</option>
					<option <?php selected('39', $displayorder); ?> value='39' /> 39: Posts, Categories, Archives, Pages, Tags</option>
					<option <?php selected('40', $displayorder); ?> value='40' /> 40: Posts, Categories, Archives, Tags, Pages</option>
					<option <?php selected('41', $displayorder); ?> value='41' /> 41: Posts, Categories, Tags, Pages, Archives</option>
					<option <?php selected('42', $displayorder); ?> value='42' /> 42: Posts, Categories, Tags, Archives, Pages</option>
					<option <?php selected('43', $displayorder); ?> value='43' /> 43: Posts, Tags, Pages, Archives, Categories</option>
					<option <?php selected('44', $displayorder); ?> value='44' /> 44: Posts, Tags, Pages, Categories, Archives</option>
					<option <?php selected('45', $displayorder); ?> value='45' /> 45: Posts, Tags, Archives, Pages, Categories</option>
					<option <?php selected('46', $displayorder); ?> value='46' /> 46: Posts, Tags, Archives, Categories, Pages</option>
					<option <?php selected('47', $displayorder); ?> value='47' /> 47: Posts, Tags, Categories, Pages, Archives</option>
					<option <?php selected('48', $displayorder); ?> value='48' /> 48: Posts, Tags, Categories, Archives, Pages</option>
					<option <?php selected('49', $displayorder); ?> value='49' /> 49: Archives, Pages, Posts, Categories, Tags</option>
					<option <?php selected('50', $displayorder); ?> value='50' /> 50: Archives, Pages, Posts, Tags, Categories</option>
					<option <?php selected('51', $displayorder); ?> value='51' /> 51: Archives, Pages, Categories, Posts, Tags</option>
					<option <?php selected('52', $displayorder); ?> value='52' /> 52: Archives, Pages, Categories, Tags, Posts</option>
					<option <?php selected('53', $displayorder); ?> value='53' /> 53: Archives, Pages, Tags, Posts, Categories</option>
					<option <?php selected('54', $displayorder); ?> value='54' /> 54: Archives, Pages, Tags, Categories, Posts</option>
					<option <?php selected('55', $displayorder); ?> value='55' /> 55: Archives, Posts, Pages, Categories, Tags</option>
					<option <?php selected('56', $displayorder); ?> value='56' /> 56: Archives, Posts, Pages, Tags, Categories</option>
					<option <?php selected('57', $displayorder); ?> value='57' /> 57: Archives, Posts, Categories, Pages, Tags</option>
					<option <?php selected('58', $displayorder); ?> value='58' /> 58: Archives, Posts, Categories, Tags, Pages</option>
					<option <?php selected('59', $displayorder); ?> value='59' /> 59: Archives, Posts, Tags, Pages, Categories</option>
					<option <?php selected('60', $displayorder); ?> value='60' /> 60: Archives, Posts, Tags, Categories, Pages</option>
					<option <?php selected('61', $displayorder); ?> value='61' /> 61: Archives, Categories, Pages, Posts, Tags</option>
					<option <?php selected('62', $displayorder); ?> value='62' /> 62: Archives, Categories, Pages, Tags, Posts</option>
					<option <?php selected('63', $displayorder); ?> value='63' /> 63: Archives, Categories, Posts, Pages, Tags</option>
					<option <?php selected('64', $displayorder); ?> value='64' /> 64: Archives, Categories, Posts, Tags, Pages</option>
					<option <?php selected('65', $displayorder); ?> value='65' /> 65: Archives, Categories, Tags, Pages, Posts</option>
					<option <?php selected('66', $displayorder); ?> value='66' /> 66: Archives, Categories, Tags, Posts, Pages</option>
					<option <?php selected('67', $displayorder); ?> value='67' /> 67: Archives, Tags, Pages, Posts, Categories</option>
					<option <?php selected('68', $displayorder); ?> value='68' /> 68: Archives, Tags, Pages, Categories, Posts</option>
					<option <?php selected('69', $displayorder); ?> value='69' /> 69: Archives, Tags, Posts, Pages, Categories</option>
					<option <?php selected('70', $displayorder); ?> value='70' /> 70: Archives, Tags, Posts, Categories, Pages</option>
					<option <?php selected('71', $displayorder); ?> value='71' /> 71: Archives, Tags, Categories, Pages, Posts</option>
					<option <?php selected('72', $displayorder); ?> value='72' /> 72: Archives, Tags, Categories, Posts, Pages</option>
					<option <?php selected('73', $displayorder); ?> value='73' /> 73: Categories, Pages, Posts, Archives, Tags</option>
					<option <?php selected('74', $displayorder); ?> value='74' /> 74: Categories, Pages, Posts, Tags, Archives</option>
					<option <?php selected('75', $displayorder); ?> value='75' /> 75: Categories, Pages, Archives, Posts, Tags</option>
					<option <?php selected('76', $displayorder); ?> value='76' /> 76: Categories, Pages, Archives, Tags, Posts</option>
					<option <?php selected('77', $displayorder); ?> value='77' /> 77: Categories, Pages, Tags, Posts, Archives</option>
					<option <?php selected('78', $displayorder); ?> value='78' /> 78: Categories, Pages, Tags, Archives, Posts</option>
					<option <?php selected('79', $displayorder); ?> value='79' /> 79: Categories, Posts, Pages, Archives, Tags</option>
					<option <?php selected('80', $displayorder); ?> value='80' /> 80: Categories, Posts, Pages, Tags, Archives</option>
					<option <?php selected('81', $displayorder); ?> value='81' /> 81: Categories, Posts, Archives, Pages, Tags</option>
					<option <?php selected('82', $displayorder); ?> value='82' /> 82: Categories, Posts, Archives, Tags, Pages</option>
					<option <?php selected('83', $displayorder); ?> value='83' /> 83: Categories, Posts, Tags, Pages, Archives</option>
					<option <?php selected('84', $displayorder); ?> value='84' /> 84: Categories, Posts, Tags, Archives, Pages</option>
					<option <?php selected('85', $displayorder); ?> value='85' /> 85: Categories, Archives, Pages, Posts, Tags</option>
					<option <?php selected('86', $displayorder); ?> value='86' /> 86: Categories, Archives, Pages, Tags, Posts</option>
					<option <?php selected('87', $displayorder); ?> value='87' /> 87: Categories, Archives, Posts, Pages, Tags</option>
					<option <?php selected('88', $displayorder); ?> value='88' /> 88: Categories, Archives, Posts, Tags, Pages</option>
					<option <?php selected('89', $displayorder); ?> value='89' /> 89: Categories, Archives, Tags, Pages, Posts</option>
					<option <?php selected('90', $displayorder); ?> value='90' /> 90: Categories, Archives, Tags, Posts, Pages</option>
					<option <?php selected('91', $displayorder); ?> value='91' /> 91: Categories, Tags, Pages, Posts, Archives</option>
					<option <?php selected('92', $displayorder); ?> value='92' /> 92: Categories, Tags, Pages, Archives, Posts</option>
					<option <?php selected('93', $displayorder); ?> value='93' /> 93: Categories, Tags, Posts, Pages, Archives</option>
					<option <?php selected('94', $displayorder); ?> value='94' /> 94: Categories, Tags, Posts, Archives, Pages</option>
					<option <?php selected('95', $displayorder); ?> value='95' /> 95: Categories, Tags, Archives, Pages, Posts</option>
					<option <?php selected('96', $displayorder); ?> value='96' /> 96: Categories, Tags, Archives, Posts, Pages</option>
					<option <?php selected('97', $displayorder); ?> value='97' /> 97: Tags, Pages, Posts, Archives, Categories</option>
					<option <?php selected('98', $displayorder); ?> value='98' /> 98: Tags, Pages, Posts, Categories, Archives</option>
					<option <?php selected('99', $displayorder); ?> value='99' /> 99: Tags, Pages, Archives, Posts, Categories</option>
					<option <?php selected('100', $displayorder); ?> value='100' /> 100: Tags, Pages, Archives, Categories, Posts</option>
					<option <?php selected('101', $displayorder); ?> value='101' /> 101: Tags, Pages, Categories, Posts, Archives</option>
					<option <?php selected('102', $displayorder); ?> value='102' /> 102: Tags, Pages, Categories, Archives, Posts</option>
					<option <?php selected('103', $displayorder); ?> value='103' /> 103: Tags, Posts, Pages, Archives, Categories</option>
					<option <?php selected('104', $displayorder); ?> value='104' /> 104: Tags, Posts, Pages, Categories, Archives</option>
					<option <?php selected('105', $displayorder); ?> value='105' /> 105: Tags, Posts, Archives, Pages, Categories</option>
					<option <?php selected('106', $displayorder); ?> value='106' /> 106: Tags, Posts, Archives, Categories, Pages</option>
					<option <?php selected('107', $displayorder); ?> value='107' /> 107: Tags, Posts, Categories, Pages, Archives</option>
					<option <?php selected('108', $displayorder); ?> value='108' /> 108: Tags, Posts, Categories, Archives, Pages</option>
					<option <?php selected('109', $displayorder); ?> value='109' /> 109: Tags, Archives, Pages, Posts, Categories</option>
					<option <?php selected('110', $displayorder); ?> value='110' /> 110: Tags, Archives, Pages, Categories, Posts</option>
					<option <?php selected('111', $displayorder); ?> value='111' /> 111: Tags, Archives, Posts, Pages, Categories</option>
					<option <?php selected('112', $displayorder); ?> value='112' /> 112: Tags, Archives, Posts, Categories, Pages</option>
					<option <?php selected('113', $displayorder); ?> value='113' /> 113: Tags, Archives, Categories, Pages, Posts</option>
					<option <?php selected('114', $displayorder); ?> value='114' /> 114: Tags, Archives, Categories, Posts, Pages</option>
					<option <?php selected('115', $displayorder); ?> value='115' /> 115: Tags, Categories, Pages, Posts, Archives</option>
					<option <?php selected('116', $displayorder); ?> value='116' /> 116: Tags, Categories, Pages, Archives, Posts</option>
					<option <?php selected('117', $displayorder); ?> value='117' /> 117: Tags, Categories, Posts, Pages, Archives</option>
					<option <?php selected('118', $displayorder); ?> value='118' /> 118: Tags, Categories, Posts, Archives, Pages</option>
					<option <?php selected('119', $displayorder); ?> value='119' /> 119: Tags, Categories, Archives, Pages, Posts</option>
					<option <?php selected('120', $displayorder); ?> value='120' /> 120: Tags, Categories, Archives, Posts, Pages</option>
				</select></td>
			</tr>
			</table>

			<div class="submit">
				<input type="submit" name="info_update" value="Update Options" />
			</div>

		</form>
	</div><?php
}

// Hooks
add_filter('the_content', 'wp_realtime_sitemap', 2);
add_action('admin_menu', 'wp_realtime_sitemap_showadmin');

?>